Index: /ipk/source/system_autoresolution_1_25/usr/lib/enigma2/python/Plugins/SystemPlugins/AutoResolution/plugin.py
===================================================================
--- /ipk/source/system_autoresolution_1_25/usr/lib/enigma2/python/Plugins/SystemPlugins/AutoResolution/plugin.py	(revision 3226)
+++ /ipk/source/system_autoresolution_1_25/usr/lib/enigma2/python/Plugins/SystemPlugins/AutoResolution/plugin.py	(revision 3227)
@@ -33,9 +33,10 @@
 config.plugins.autoresolution.deinterlacer_progressive = ConfigSelection(default = "auto", choices =
 		[("off", _("off")), ("auto", _("auto")), ("on", _("on")), ("bob", _("bob"))])
-config.plugins.autoresolution.delay_switch_mode = ConfigSelection(default = "6000", choices = [
-		("1000", "1 " + _("second")), ("2000", "2 " + _("seconds")), ("3000", "3 " + _("seconds")),
+config.plugins.autoresolution.delay_switch_mode = ConfigSelection(default = "1", choices = [
+		("1", "off"), ("1000", "1 " + _("second")), ("2000", "2 " + _("seconds")), ("3000", "3 " + _("seconds")),
 		("4000", "4 " + _("seconds")), ("5000", "5 " + _("seconds")), ("6000", "6 " + _("seconds")), ("7000", "7 " + _("seconds")),
 		("8000", "8 " + _("seconds")), ("9000", "9 " + _("seconds")), ("10000", "10 " + _("seconds"))])
 ####### Husky default delay set to 6000 
 
 def setDeinterlacer(mode):
@@ -159,5 +160,5 @@
 			framerate = info and info.getInfo(iServiceInformation.sFrameRate)
 
-			if height != -1 and width != -1 and framerate != -1:
+			if height > 0 and width > 0 and framerate > 0:
 				frate = str(framerate)[:2] #fallback?
 				if frqdic.has_key(framerate):
@@ -166,8 +167,8 @@
 				prog = progressive == 1 and 'p' or 'i'
 
-				if (height >= 900 or width >= 1600) and frate in ('24', '25', '30') and prog == 'p':		# 1080p content
+				if (height >= 900 or width >= 1600) and frate in ('24', '25', '30') and prog == 'p': 	# 1080p content
 					new_mode = 'p1080_%s' % frate
 ######## HUSKY NEW 720p 
-				elif (height > 576 or width > 720) and frate == '50' :		# 720p 50Hz detection
+				elif (height > 576 or width > 720) and frate == '50' : 	                 	# 720p 50Hz detection
 						prog = 'p'
 						new_mode = 'hd_%s' % prog
@@ -182,5 +183,5 @@
 					new_mode = 'hd_%s' % prog
 
-				if  progressive == 1 or prog == 'p':	####### HUSKY or prog added
+				if  progressive == 1 or prog == 'p':						####### HUSKY or prog added
 					setDeinterlacer(config.plugins.autoresolution.deinterlacer_progressive.value)
 
@@ -33,9 +33,10 @@
 		("4000", "4 " + _("seconds")), ("5000", "5 " + _("seconds")), ("6000", "6 " + _("seconds")), ("7000", "7 " + _("seconds")),
 		("8000", "8 " + _("seconds")), ("9000", "9 " + _("seconds")), ("10000", "10 " + _("seconds"))])
-####### Husky default delay set to 6000 
+####### add 1ms (delay= off)
+####### Husky default delay set to 1 (delay=off) 
 
 def setDeinterlacer(mode):
